ZoneRef

Enum ZoneRef 

pub enum ZoneRef {
    Tz(Tz),
    Location(&'static Location),
}
Reference to a timezone.

Variants



Tz(Tz)



Location(&'static Location)

Implementations

Source

impl ZoneRef

pub fn name(&self) -> &str

Returns the name of the zone reference.

For actual timezones that can be the IANA name, for cities and airports this will be the actual name of the location.

pub fn is_utc(&self) -> bool

True if this zone is the UTC zone.

Note that this is different than checking if the zone is currently at UTC+0.

pub fn kind(&self) -> LocationKind

Returns the kind of location.

pub fn country(&self) -> Option<&str>

If this zone reference points to a country, returns the country name.

pub fn admin_code(&self) -> Option<&str>

If the zone has an admin code returns it.

For the US for instance this can be the name of the US state.

pub fn tz(&self) -> Tz

Returns a chrono_tz timezone object.